AEHardwareInfo class

Constructors

AEHardwareInfo({required String backendName, required String deviceName, required AudioFormat outputFormat, required int bitDepth, required bool isFloat, required int sampleRate, required int channels, required int periodSizeFrames, required int periodCount, required double latencyMs, required bool isExclusiveMode})
const
AEHardwareInfo.fromNative(AEHardwareInfoNative native)
factory

Properties

backendName String
final
bitDepth int
final
channels int
final
deviceName String
final
hashCode int
The hash code for this object.
no setterinherited
isExclusiveMode bool
final
isFloat bool
final
latencyMs double
final
outputFormat AudioFormat
final
periodCount int
final
periodSizeFrames int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited