AEHardwareInfoNative class final

Inheritance
Implemented types
Available extensions

Constructors

AEHardwareInfoNative()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
backend_name Array<Uint8>
getter/setter pair
bit_depth int
getter/setter pair
channels int
getter/setter pair
device_name Array<Uint8>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
is_exclusive_mode int
getter/setter pair
is_float int
getter/setter pair
latency_ms double
getter/setter pair
output_format int
getter/setter pair
period_count int
getter/setter pair
period_size_frames int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sample_rate int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited