AETrackInfoNative class final

Inheritance
Implemented types
Available extensions

Constructors

AETrackInfoNative()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bit_depth int
getter/setter pair
bitrate_kbps int
getter/setter pair
channels int
getter/setter pair
duration_secs double
getter/setter pair
file_size_bytes int
getter/setter pair
format_name Array<Uint8>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
is_float int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sample_rate int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited