getClippedSamplesCount method
Returns the total number of clipped samples since the last reset.
Implementation
int getClippedSamplesCount() {
if (_engine == ffi.nullptr) return 0;
return _getClippedSamplesCount(_engine);
}
Returns the total number of clipped samples since the last reset.
int getClippedSamplesCount() {
if (_engine == ffi.nullptr) return 0;
return _getClippedSamplesCount(_engine);
}