AudioSource class
Constructors
- AudioSource.file(String path, {String? title, String? artist, Duration? duration})
-
factory
- AudioSource.network(String url, {String? title, String? artist, Duration? duration})
-
factory
- AudioSource.uri(Uri uri, {String? title, String? artist, Duration? duration})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromM3u(
String pathOrUrl) → Future< List< AudioSource> > - Asynchronously loads an M3U/M3U8 playlist from a local file path or remote HTTP/HTTPS URL and expands it into a List<AudioSource>.
-
fromM3uContent(
String content, {String? baseDirectory}) → List< AudioSource> - Parses an M3U/M3U8 playlist string and expands it into a list of AudioSource instances.