PipelineAudioState class
Constructors
- PipelineAudioState({required int inputFormat, required int inputSampleRate, required int inputChannels, required int processingFormat, required int processingSampleRate, required int processingChannels, required int outputFormat, required int outputSampleRate, required int outputChannels, required bool eqEnabled, required bool reverbEnabled, required bool limiterEnabled, required bool stereoWidenEnabled, required bool spatializationEnabled, required bool delayEnabled, required double gain, required double pan, required double pitch})
-
const
- PipelineAudioState.empty()
-
factory
- PipelineAudioState.fromNative(PipelineStateNative native)
-
factory
Properties
- delayEnabled → bool
-
final
- eqEnabled → bool
-
final
- gain → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputChannels → int
-
final
- inputFormat → int
-
final
- inputFormatString → String
-
no setter
- inputSampleRate → int
-
final
- limiterEnabled → bool
-
final
- outputChannels → int
-
final
- outputFormat → int
-
final
- outputFormatString → String
-
no setter
- outputSampleRate → int
-
final
- pan → double
-
final
- pitch → double
-
final
- processingChannels → int
-
final
- processingFormat → int
-
final
- processingFormatString → String
-
no setter
- processingSampleRate → int
-
final
- reverbEnabled → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spatializationEnabled → bool
-
final
- stereoWidenEnabled → bool
-
final
Methods
-
formatToString(
int format) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited