TrackNativeInfo class

Constructors

TrackNativeInfo({required int sampleRate, required int bitDepth, required int channels, required int bitrateKbps, required bool isFloat, required double durationSecs, required int fileSizeBytes, required String formatName})
const
TrackNativeInfo.fromNative(AETrackInfoNative native)
factory

Properties

bitDepth int
final
bitrateKbps int
final
channels int
final
durationSecs double
final
fileSizeBytes int
final
formatName String
final
hashCode int
The hash code for this object.
no setterinherited
isFloat bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited