ViperDynamicEqBand class

Constructors

ViperDynamicEqBand({double frequencyHz = 1000.0, double q = 1.0, double gainDb = 0.0, double thresholdDb = 0.0, double attackMs = 20.0, double releaseMs = 100.0, int filterType = 0})

Properties

attackMs double
getter/setter pair
filterType int
getter/setter pair
frequencyHz double
getter/setter pair
gainDb double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
q double
getter/setter pair
releaseMs double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thresholdDb double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeToArray(Float32List arr, int offset) → void
The C struct layout is 7 floats. 0frequency_hz 1q 2gain_db 3threshold_db 4attack_ms 5release_ms 6filter_type

Operators

operator ==(Object other) bool
The equality operator.
inherited